' Windows Script Host Sample Script
'
' ------------------------------------------------------------------------
'               Copyright (C) Software Bisque
'
' ------------------------------------------------------------------------
Option Explicit

Dim L_Welcome_MsgBox_Message_Text
Dim L_Welcome_MsgBox_Title_Text
Dim L1

Dim CRLF
CRLF = Chr(13) & Chr(10)

L1 = "This script demonstrates how to acquire images from a list of targets in a text file.  " + CRLF + CRLF
L1 = L1 + "Use TheSky's data export command to create a Simple List of objects that meet your desired criteria.  "
L1 = L1 + "For example, you can easily generate a list of all Messier objects within an hour of the meridian.  "
L1 = L1 + "Or you can generate a list of all PGC galaxies with a magnitude greater than 13 and a size between 10 and 20 arc minutes.  "+CRLF + CRLF
L1 = L1 + "See the function InitGlobalUserVariables to set the path to your list of targets, set the exposure time, etc."

L_Welcome_MsgBox_Message_Text    = L1
L_Welcome_MsgBox_Title_Text      = "Windows Scripting Host Sample"


'FYI Any line preceded by a single quote is ignored or a comment line
'If you are using this script to image satellites, add a line to slew to them twice!

'Global Objects
Dim objTheSky
Dim objTele
Dim objCam

'Global User Variables see InitGlobalUserVariables()
Dim szPathToTargetFile
Dim dExposure
Dim	nTimes


' ********************************************************************************
' *
' * Below is the flow of program execution
' * See the subroutine TargetLoop to for where the real work is done

Call Welcome()
Call InitGlobalUserVariables()
Call CreateObjects()
Call ConnectObjects()
Call TargetLoop()
Call DisconnectObjects()
Call DeleteObjects()


' ********************************************************************************
' *
' * Below are all the subroutines used in this sample
' *
Sub Welcome()
    Dim intDoIt

    intDoIt =  MsgBox(L_Welcome_MsgBox_Message_Text, _
                      vbOKCancel + vbInformation,    _
                      L_Welcome_MsgBox_Title_Text )
    If intDoIt = vbCancel Then
        WScript.Quit
    End If
End Sub

Sub InitGlobalUserVariables()

	'Use TheSky's Data Export command to quickly and easily 
	'generate a text file of target objects
	'The default is below
	szPathToTargetFile = "D:\Program Files\Software Bisque\TheSky\User\Exported Data\Target.txt"

	'Enter the length of the exposure for the desired image
	dExposure = 1.0
	
	'Enter the number of times you want to run thru the szPathToTargetFile file
	'Typically it is one, but for light curve data collection on 
	'selected variable stars or minor planets it may be more, 
	nTimes = 1

End Sub


Sub GetDataFromTextFile(LineFromFile, szTargetName, dRa, dDec)

	szTargetName= Mid(LineFromFile,1,18)
	dRa			= CDbl(Mid(LineFromFile,45,11))
	dDec		= CDbl(Mid(LineFromFile,61,11))

End Sub


Sub PromptOnError(bErrorOccurred)

	Dim bExitScript

	bErrorOccurred = False
	bExitScript = False

	if (Err.Number) then 
		bErrorOccurred = True
		bExitScript = MsgBox ("An error has occurred running this script.  Error # " & CStr(Hex(Err.Number)) & " " & Err.Description + CRLF + CRLF + "Exit Script?", vbYesNo + vbInformation)
	end if

	If bExitScript = vbYes Then
		WScript.Quit
	End if 

End Sub

Sub TargetLoop()
	'On Error Resume Next
	Dim TxtFile
	Dim fso
	Const ForReading = 1
	Dim dRa
	Dim dDec
	Dim bErrorOccurred
	Dim szTargetName
	Dim nCount

	for nCount=1 to nTimes 
		Set fso = CreateObject("Scripting.FileSystemObject")
		Set TxtFile = fso.OpenTextFile(szPathToTargetFile, ForReading)

		Do While (TxtFile.AtEndOfStream <> True)

			Err.Clear 'Clear the error object
			bErrorOccurred = FALSE 'No error has occurred
			
			Call GetDataFromTextFile(TxtFile.ReadLine, szTargetName, dRa, dDec)

			if (bErrorOccurred = False) then
				Call objTele.SlewToRaDec(dRa, dDec, szTargetName)
				Call PromptOnError(bErrorOccurred)
			end if
			
			if (bErrorOccurred = False) then
				objCam.ExposureTime = dExposure
				Call objCam.TakeImage()
				Call PromptOnError(bErrorOccurred)
			end if
		Loop

		Set fso = Nothing
		Set TxtFile = Nothing
	Next

	MsgBox("Done")
End Sub


Sub CreateObjects()
	Set objTheSky = WScript.CreateObject("RASCOM.RASCOMTheSky.1")
	Set objTele = WScript.CreateObject("RASCOM.RASCOMTele.1")
	Set objCam = WScript.CreateObject("CCDSoft.Camera")
	objCam.AutoSaveOn = 1
End Sub

Sub ConnectObjects()
	objTheSky.Connect()
	objTele.Connect()
	objCam.Connect()
End Sub

Sub DisconnectObjects()
	objTheSky.Disconnect()
	objTele.Disconnect()
	objCam.Disconnect()
End Sub 

Sub DeleteObjects()
	Set objTheSky = Nothing
	Set objTele = Nothing
	Set objCam = Nothing
End Sub 

	
