#!/usr/bin/python
# 
# Generate rise and set times for the Sun at Moore Observatory using PyEphem
#

# Import functions

from ephem import *
from datetime import datetime, timedelta
from pytz import timezone, all_timezones
from math import floor, pi
from re import *
from time import gmtime
import cgi

# Use these lines to debug the script

import cgitb
cgitb.enable()

# Default parameters for Moore Observatory
moorelat     = '38:20:40'; 
moorelong    = '-85:31:44'; 
adate        = (2009,10,15,12,0,0)
mooremajor   = 'US'
moorezone    = 'Eastern'

latitude     = moorelat
longitude    = moorelong
dfltmajor    = mooremajor
dfltzone     = moorezone

action       = 'majors'

HUGEDAYS     = 1000*365.25

lunarperiod  = 29.530588853

########################################################################
# Converts an ephem UTC date to a local time hh:mm
def ut2ltstr(adate):
  dtuple = list(adate.tuple())
  dtuple[5] = int(floor(dtuple[5]))
  ut     = apply(datetime,dtuple,{'tzinfo':timezone('UTC')})
  lt     = ut.astimezone(tz)
  return lt.strftime('%H:%M')


########################################################################
# Converts an ephem UTC date to a local time yyyy mmm dd hh:mm:ss
def ut2ltstr2(adate):
  dtuple = list(date(adate).tuple())
  dtuple[5] = int(floor(dtuple[5]))
  ut     = apply(datetime,dtuple,{'tzinfo':timezone('UTC')})
  lt     = ut.astimezone(tz)
  return lt.strftime('%Y %b %d %H:%M:%S')

########################################################################
# Converts an ephem UTC date to a local date string yyyy mmm dd
def ut3ltstr(adate):
  dtuple = list(adate.tuple())
  dtuple[5] = int(floor(dtuple[5]))
  ut     = apply(datetime,dtuple,{'tzinfo':timezone('UTC')})
  lt     = ut.astimezone(tz)
  return lt.strftime('%Y %b %d')

########################################################################
def GetTimeZones():
  global majors, minors
  re1  = compile(r'(\w+)/([\w+-_]+)')
  re2  = compile(r'([\w+-]+)')
  tzs  = all_timezones
  lth  = len(tzs); i = 0;
  lastMaj = []
  while i<lth:
    tz = tzs[i]
    amatch = re1.search(tz)
    if amatch:
      maj = amatch.group(1)
      if maj != lastMaj:
        lastMaj = maj
        majors.append(maj)
      if maj == reqmajor:
        minors.append(amatch.group(2))
    else:
      amatch = re2.search(tz)
      if (amatch) and (reqmajor == 'Misc'):
        minors.append(amatch.group(1))
    i += 1
  majors.append('Misc')
 

########################################################################
# Set adate to timezone time for today at this time
def setadate():
  global tzstr
  tzstr = dfltmajor + '/' + dfltzone
  utl    = list(gmtime())
  utl    = utl[0:6]
  utzone = timezone('UTC')
  ut     = apply(datetime,utl,{'tzinfo': utzone})
  ltzone = timezone(tzstr)
  lt     = ut.astimezone(ltzone)
  ltstr  = lt.strftime('%Y %m %d %H %M %S')     # %H %M %S added Dec 2007
  lst    = ltstr.split()
  for i in range(6):
    lst[i] = int(lst[i])
  return lst

########################################################################


# Moore Observatory

reqmajor     = dfltmajor
reqzone      = dfltzone

# Retrieve the timezones
majors   = []; minors = []; 
GetTimeZones()

# Generate the location

locn     = Observer()
locn.lat = moorelat; 
locn.long = moorelong;
dfltmajor = mooremajor
dfltzone  = moorezone

# Generate full timezone string

adate = setadate() 


tz       = timezone(tzstr)
tt       = apply(datetime,adate)              
lt       = tz.localize(tt,is_dst = True)      
ldatestr = lt.strftime('%Y %b %d  %H:%M:%S')   
ndatestr = lt.strftime('%Y %m %d %H %M %S')   
offsstr  = lt.strftime('%z')
prev     = lt - timedelta(hours = 24)
prevstr  = prev.strftime('%Y %b %d')
ut       = lt.astimezone(timezone('UTC'))
utstr    = ut.strftime('%Y/%m/%d %H:%M:%S')
utstr2   = ut.strftime('%Y %b %d %H:%M:%S')

# Generate the data

sset = []; 
srise = []; 


datestr = ut.strftime('%Y/%m/%d')
locn.date    = datestr
sun = Sun() 
moon = Moon()

# Do rise and set ut

locn.horizon =     '0.0'                             

srise = locn.next_rising(sun)
azsrise = sun.az

sset = locn.next_setting(sun)
azsset = sun.az 

strans = locn.next_transit(sun)
altstrans = sun.alt

mrise = locn.next_rising(moon)
azmrise = moon.az

mtrans = locn.next_transit(moon)
altmtrans = moon.alt

mset = locn.next_setting(moon)
azmset = moon.az 

# Output local times for this zone

srise = ut2ltstr2(srise)
sset = ut2ltstr2(sset)
print str(sset) 
print str(srise) 

