/* -------------------------------------------------------------------------- */
/* -                   Astronomical Telescope Control                       - */
/* -                         XmTel Header File                              - */
/* -------------------------------------------------------------------------- */
/*                                                                            */
/* Copyright (c) 2009-2012 John Kielkopf                                      */
/* kielkopf@louisville.edu                                                    */
/*                                                                            */
/* This file is part of XmTel.                                                */
/*                                                                            */
/* Distributed under the terms of the General Public License (see LICENSE)    */ 
/*                                                                            */
/* Date: March 26, 2012                                                       */
/* Version: 6.0                                                               */

/* Important physical constants */

#ifndef PI
#define PI             3.14159265358
#endif

/* Useful values */

#ifndef FALSE
#define FALSE 0
#endif

#ifndef TRUE
#define TRUE 1
#endif

/* Menu flags */

#define OK         1     
#define CANCEL     2

/* Menu item identifiers */

#define NEWQUEUE        1
#define NEWLOG          2
#define NEWCONFIG       3
#define EXIT            4
#define EDITQUEUE       5 
#define EDITLOG         6 
#define EDITCONFIG      7
#define POINTOPTION1    8
#define POINTOPTION2    9
#define POINTOPTION4   10
#define POINTOPTION8   11
#define REFTARGET      12
#define REFWCS         13
#define REFCLEAR       14
#define REFSAVE        15
#define REFRECALL      16
#define REFDEFAULT     17
#define MODELEDIT      18
#define MODELCLEAR     19
#define MODELSAVE      20
#define MODELRECALL    21
#define MODELDEFAULT   22


#define FOCUS          23
#define ROTATE         24
#define FAN            25
#define HEATER         26


/* Focus panel identifiers */

#define FOCUSIN        1
#define FOCUSOUT       2
#define FOCUSOK        4

/* Rotate panel identifiers */

#define ROTATECW       1
#define ROTATECCW      2
#define ROTATEOK       3

/* Fan panel identifiers */

#define FANOK          1

/* Heater panel identifiers */

#define HEATEROK       1

/* Target input flags */

#define RA        1               
#define DEC       2               

/* Reserve space for characters in file descriptors */

#define MAXPATHLEN  100

/* Default log and queue files */

#define LOGFILE   "telescope.log"
#define QUEUEFILE "target.que"


/* Default log and queue editor e.g. nedit or gedit */

#define XMTEL_EDITOR  "nedit"


/* INDI */

#define INDIPORT	7624	/* default port */

/* Diagnostic flag */
/* Set to 0 to disable, 1 to see XML, 2 to see selected flags and values */

#define  DIAGNOSTICS     0

/* In xmtel1 and tel the following are defined in protocol.h */
/* They are needed here to ease building the user interface */

/* Slew motion speeds */

#define	GUIDE		1
#define	CENTER		2
#define	FIND		4
#define	SLEW		8

/* Slew directions */

#define	NORTH		1
#define	SOUTH		2
#define	EAST		4
#define	WEST		8

/* Pointing models (bit mapped and additive) */

#define RAW       0      /* Unnmodified but assumed zero corrected */
#define OFFSET    1      /* Correct for target offset*/
#define REFRACT   2      /* Correct for atmospheric refraction */
#define POLAR     4      /* Correct for polar axis misalignment */ 
#define DYNAMIC   8      /* Correct for errors in real time */

/* Display epochs (selected with GUI button) */

#define J2000    0      /* Epoch 2000.0 as entered or precessed without pm */
#define EOD      1      /* Epoch of date with pm if available  (default) */

/* Target set commands */

#define TARGETCMDOFF      0
#define TARGETCMDZENITH   1
#define TARGETCMDMERIDIAN 2
#define TARGETCMDPARK     3

/* Focus commands  */

#define FOCUSSPD4           8   /* Fast    */
#define FOCUSSPD3           4   /* Medium  */
#define FOCUSSPD2           2   /* Slow    */
#define FOCUSSPD1           1   /* Precise */

#define FOCUSCMDOUT         2   /* CCD moves away from sky */
#define FOCUSCMDIN          1   /* CCD moves toward the  sky */
#define FOCUSCMDOFF         0   /* CCD does not move */

/* Rotator commands */

#define ROTATECMDOFF        0   /* Camera does not rotate */
#define ROTATESPDSIDEREAL   1   /* Sidereal rate */
#define ROTATESPDSLOW       2   /* Slow set */
#define ROTATESPDFAST       4   /* Fast set */
#define ROTATECMDCCW        8   /* Camera rotates CCW looking toward the sky */
#define ROTATECMDCW        16   /* Camera rotates CW looking toward the sky */

/* Fan commands */

#define FANCMDOFF       0   /* cooling fan off */
#define FANCMDLOW       1   /* cooling fan on low speed */
#define FANCMDHIGH      2   /* cooling fan on high speed */

/* Heater commands */

#define HEATERCMDOFF       0   /* dew heater off */
#define HEATERCMDLOW       1   /* dew heater on low */
#define HEATERCMDHIGH      2   /* dew heater on high */

/* User interface feature flags */

#define FOCUSDISABLED   0      /* If greater than 0 function is disabled */
#define ROTATEDISABLED  0      /* If greater than 0 function is disabled */
#define THERMALDISABLED 0      /* If greater than 0 function is disabled */
#define HEATERDISABLED  0      /* If greater than 0 function is disabled */

